rapidsms-twilio
===============

`Twilio`_ backend for the `RapidSMS`_ project. Uses `python-twilio`_ to communicate with Twilio.

.. image::
    https://api.travis-ci.org/caktus/rapidsms-twilio.png?branch=develop
    :alt: Build Status
    :target: http://travis-ci.org/caktus/rapidsms-twilio

Features
--------

* Compatible with RapidSMS v0.13+
* Support for Twilio's `status callback <http://www.twilio.com/docs/api/rest/sending-sms#post-parameters-optional>`_

Installation
-------------

rapidsms-twilio requires Django >= 1.3 and Python >= 2.6.

To install from PyPi::
    
    pip install rapidsms-twilio

Documentation
-------------

Documentation on using rapidsms-twilio is available on 
`Read The Docs <http://readthedocs.org/docs/rapidsms-twilio/>`_.


License
-------

rapidsms-twilio is released under the BSD License. See the  `LICENSE
<https://github.com/caktus/rapidsms-twilio/blob/master/LICENSE.txt>`_ file for
more details.

Contributing
------------

If you think you've found a bug or are interested in contributing to this
project check out `rapidsms-twilio on Github <https://github.com/caktus
/rapidsms-twilio>`_.

Development by `Caktus Consulting Group <http://www.caktusgroup.com/>`_.

.. _RapidSMS: http://www.rapidsms.org/
.. _Twilio: http://www.twilio.com
.. _python-twilio: http://pypi.python.org/pypi/twilio
